pub struct Cli {
pub verb: Verb,
pub json: bool,
pub form: bool,
pub raw: Option<String>,
pub output: Option<String>,
pub download: bool,
pub auth: Option<String>,
pub follow: bool,
pub max_redirects: usize,
pub verify: CliBool,
pub verbose: bool,
}Fields
verb: Verbjson: booldata items from the command line are serialized as a JSON object
form: booldata items from the command line are serialized as form fields
raw: Option<String>allows you to pass raw request data without extra processing
output: Option<String>save output to file instead of stdout
download: booldo not print the response body to stdout; rather, download it and store it in a file
auth: Option<String>basic authentication (user[:password]) or bearer token
follow: boolfollows Location redirects
max_redirects: usizewhen following redirects, max redirects
verify: CliBoolset to “no” (or “false”) to skip checking the host’s SSL certificate
verbose: boolShow headers
Implementations