kodumaro_http_cli

Struct Cli

source
pub struct Cli {
Show 13 fields pub json: bool, pub form: bool, pub multipart: bool, pub boundary: Option<String>, pub raw: Option<String>, pub output: Option<String>, pub download: bool, pub auth: Option<String>, pub follow: bool, pub max_redirects: usize, pub verify: CliBool, pub verbose: bool, pub verb: Verb,
}

Fields

json: bool

data items from the command line are serialized as a JSON object

form: bool

data items from the command line are serialized as form fields

multipart: bool

similar to –form, but always sends a multipart/form-data request (i.e., even without files)

boundary: Option<String>

specifies a custom boundary string for multipart/form-data requests

raw: Option<String>

allows you to pass raw request data without extra processing

output: Option<String>

save output to file instead of stdout

download: bool

do not print the response body to stdout; Rather, download it and store it in a file

auth: Option<String>

basic authentication (user[:password])

follow: bool

follows Location redirects

max_redirects: usize

by default, requests have a limit of 30 redirects

verify: CliBool

set to “no” (or “false”) to skip checking the host’s SSL certificate; defaults to “yes” (“true”)

verbose: bool

Show headers

verb: Verb

Implementations