pub struct Cli {}Fields
json: booldata items from the command line are serialized as a JSON object
form: booldata items from the command line are serialized as form fields
multipart: boolsimilar to –form, but always sends a multipart/form-data request (i.e., even without files)
boundary: Option<String>specifies a custom boundary string for multipart/form-data requests
raw: Option<String>allows you to pass raw request data without extra processing
output: Option<String>save output to file instead of stdout
download: booldo not print the response body to stdout; Rather, download it and store it in a file
auth: Option<String>basic authentication (user[:password])
follow: boolfollows Location redirects
max_redirects: usizeby default, requests have a limit of 30 redirects
verify: CliBoolset to “no” (or “false”) to skip checking the host’s SSL certificate; defaults to “yes” (“true”)
verbose: boolShow headers
verb: VerbImplementations